========================================================
qiprofile-rest: Quantitative Imaging Profile REST server
========================================================

Displays the OHSU QIN images and annotations. See the
`documentation <http://qiprofile-rest.readthedocs.org/en/latest/>`_
for more information.

